@@ -10,6 +10,7 @@
 
 import os
 import sys
+import platform
 import warnings
 
 import numpy
@@ -19,7 +20,7 @@ from numpy import (
     sum, prod, sqrt, fmod,
     sin, cos, tan, arcsin, arccos, arctan, arctan2,
     sinh, cosh, tanh, arcsinh, arccosh, arctanh,
-    log, log1p, log10, exp, expm1)
+    log, log1p, log10, exp, expm1, conj)
 from numpy.testing import (assert_equal, assert_array_equal,
     assert_array_almost_equal, assert_allclose)
 from numpy import shape, allclose, array_equal, ravel, isnan, isinf
@@ -206,14 +207,14 @@ class test_evaluate(TestCase):
 
     # PyTables uses __nonzero__ among ExpressionNode objects internally
     # so this should be commented out for the moment.  See #24.
-    # def test_boolean_operator(self):
-    #     x = arange(10, dtype='i4')
-    #     try:
-    #         evaluate("(x > 1) and (x < 9)")
-    #     except TypeError:
-    #         pass
-    #     else:
-    #         raise ValueError("should raise exception!")
+    def test_boolean_operator(self):
+        x = arange(10, dtype='i4')
+        try:
+            evaluate("(x > 1) and (x < 9)")
+        except TypeError:
+            pass
+        else:
+            raise ValueError("should raise exception!")
 
     def test_rational_expr(self):
         a = arange(1e6)
@@ -279,23 +280,24 @@ class test_evaluate(TestCase):
         else:
             self.fail()
 
-    # Execution order set here so as to not use too many threads
-    # during the rest of the execution.  See #33 for details.
-    def test_changing_nthreads_00_inc(self):
-        a = linspace(-1, 1, 1e6)
-        b = ((.25*a + .75)*a - 1.5)*a - 2
-        for nthreads in range(1,7):
-            numexpr.set_num_threads(nthreads)
-            c = evaluate("((.25*a + .75)*a - 1.5)*a - 2")
-            assert_array_almost_equal(b, c)
+    if 'sparc' not in platform.machine():
+        # Execution order set here so as to not use too many threads
+        # during the rest of the execution.  See #33 for details.
+        def test_changing_nthreads_00_inc(self):
+            a = linspace(-1, 1, 1e6)
+            b = ((.25*a + .75)*a - 1.5)*a - 2
+            for nthreads in range(1,7):
+                numexpr.set_num_threads(nthreads)
+                c = evaluate("((.25*a + .75)*a - 1.5)*a - 2")
+                assert_array_almost_equal(b, c)
 
-    def test_changing_nthreads_01_dec(self):
-        a = linspace(-1, 1, 1e6)
-        b = ((.25*a + .75)*a - 1.5)*a - 2
-        for nthreads in range(6, 1, -1):
-            numexpr.set_num_threads(nthreads)
-            c = evaluate("((.25*a + .75)*a - 1.5)*a - 2")
-            assert_array_almost_equal(b, c)
+        def test_changing_nthreads_01_dec(self):
+            a = linspace(-1, 1, 1e6)
+            b = ((.25*a + .75)*a - 1.5)*a - 2
+            for nthreads in range(6, 1, -1):
+                numexpr.set_num_threads(nthreads)
+                c = evaluate("((.25*a + .75)*a - 1.5)*a - 2")
+                assert_array_almost_equal(b, c)
 
 
 tests = [
@@ -341,7 +343,7 @@ func1tests = []
 for func in ['copy', 'ones_like', 'sqrt',
              'sin', 'cos', 'tan', 'arcsin', 'arccos', 'arctan',
              'sinh', 'cosh', 'tanh', 'arcsinh', 'arccosh', 'arctanh',
-             'log', 'log1p', 'log10', 'exp', 'expm1', 'abs']:
+             'log', 'log1p', 'log10', 'exp', 'expm1', 'abs', 'conj']:
     func1tests.append("a + %s(b+c)" % func)
 tests.append(('1_ARG_FUNCS', func1tests))
 
@@ -767,7 +769,8 @@ def suite():
 
     for n in range(niter):
         theSuite.addTest(unittest.makeSuite(test_numexpr))
-        theSuite.addTest(unittest.makeSuite(test_numexpr2))
+        if 'sparc' not in platform.machine():
+            theSuite.addTest(unittest.makeSuite(test_numexpr2))
         theSuite.addTest(unittest.makeSuite(test_evaluate))
         theSuite.addTest(unittest.makeSuite(TestExpressions))
         theSuite.addTest(unittest.makeSuite(test_int32_int64))
